@@ -12,19 +12,21 @@
 #include <string.h>
 #include <stdlib.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
+#endif
 
 #ifdef TCL_WRAPPER
 #include <tk.h>
 #else
-
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #include "Xw/Form.h"
 #include "Xw/WorkSpace.h"
 #include "Xw/MenuBtn.h"
-
+#endif
 #endif
 
 /*----------------------------------------------------------------------*/
@@ -48,7 +50,7 @@
 extern Tcl_Interp *xcinterp;
 #endif
 
-#ifndef TCL_WRAPPER
+#if !defined(TCL_WRAPPER)
 
 extern Display    *dpy;
 extern GC	  hgc;
@@ -80,16 +82,11 @@ void printhelppix()
 {
    static char *helptitle = "Macro Key Binding Summary:";
    static helpstruct helptext[] = {
-    { XCF_Start,	"Start"},
     { XCF_Finish,	"Finish"},
     { XCF_Cancel,	"Cancel"},
     { XCF_Zoom_In,	"Zoom in 3/2"},
     { XCF_Zoom_Out,	"Zoom out 3/2"},
-    { XCF_Pan,		"Pan to center"},
-    { XCF_Pan_Up,	"Half-page pan Up"},
-    { XCF_Pan_Down,	"Half-page pan Down"},
-    { XCF_Pan_Right,	"Half-page pan Right"},
-    { XCF_Pan_Left,	"Half-page pan Left"},
+    { XCF_Pan,		"Pan (various modes)"},
     { XCF_Double_Snap,	"Double snap-to spacing"},
     { XCF_Halve_Snap,	"Halve snap-to spacing"},
     { XCF_Next_Library,	"Go To Next Library"},
@@ -302,6 +299,8 @@ void printhelppix()
 /* Create the help popup window	(Xt version)	*/
 /*----------------------------------------------*/
 
+#ifndef XC_WIN32
+
 void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
 {
    Arg		wargs[11];
@@ -500,6 +499,8 @@ void printhelp(xcWidget hspace)
    while (XCheckWindowEvent(dpy, hwin, ExposureMask, &discard) == True);
 }
 
+#endif
+
 /*----------------------------------------------------------------------*/
 /* The TCL version assumes the existence of command "helpwindow".	*/
 /*----------------------------------------------------------------------*/
