@@ -573,7 +573,6 @@ extern void invalidate_netlist(objectptr);
 extern void remove_netlist_element(objectptr, genericptr);
 extern int updatenets(objinstptr);
 extern void createnets(objinstptr);
-extern void destroynets();
 extern Boolean nonnetwork(polyptr);
 extern int globalmax();
 extern LabellistPtr geninfolist(objectptr, objinstptr, char *);
@@ -839,7 +838,7 @@ extern void popupprompt(xcWidget, char *, char *, void (*function)(),
 extern void getproptext(xcWidget, propstruct *, caddr_t);
 extern int rgb_alloccolor(int, int, int);
 extern void addtocolorlist(xcWidget, int);
-extern void addnewcolorentry(int);
+extern int addnewcolorentry(int);
 extern int xc_getlayoutcolor(int);
 extern void outputpopup(xcWidget, caddr_t, caddr_t);
 extern void docommand();
